@@ -26,7 +26,8 @@ from argparse import Namespace
 from argparse import _SubParsersAction as SubParsersAction
 
 from .errors import InternalResponseError
-from .handlers.api import API
+from .handlers.api import RequestBuilder
+from .handlers.api import request
 from .handlers.toml import TOML
 
 
@@ -85,20 +86,23 @@ def server_notice(arg: Namespace) -> int:
 
     """
     toml: TOML = TOML()
-    api: API = API(toml.get("API", "Domain"), toml.get("API", "Token"))
-    request = {
-        "user_id": (f"@{arg.username}:" f"{toml.get('API', 'Domain')}"),
-        "content": {
-            "msgtype": "m.text",
-            "body": arg.message,
+    req: RequestBuilder = RequestBuilder(
+        token=toml.get("API", "Token"),
+        domain=toml.get("API", "Domain"),
+        path="send_server_notice",
+        method="POST",
+        api_version="v1",
+        data={
+            "user_id": (f"@{arg.username}:" f"{toml.get('API', 'Domain')}"),
+            "content": {
+                "msgtype": "m.text",
+                "body": arg.message,
+            },
         },
-    }
+    )
 
     try:
-        api.url.path = "send_server_notice"
-        api.url.api_version = "v1"
-        api.method = "POST"
-        api.request(request)
+        request(req)
     except InternalResponseError:
         logger.error("The server notice was not sent.")
 
