@@ -20,9 +20,8 @@
 from __future__ import annotations
 
 from typing import Any
-from typing import Dict
 
 
-JsonDict = Dict[str, Any]
+JsonDict = dict[str, Any]
 
 # vim: set ft=python :
