@@ -14,6 +14,9 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+"""Use this module to add the ``update`` subcommand to ``matrixctl``."""
+
 from __future__ import annotations
 
 from argparse import ArgumentParser
@@ -29,6 +32,18 @@ __email__: str = "Michael@MichaelSasser.org"
 
 
 def subparser_update(subparsers: SubParsersAction) -> None:
+    """Create a subparser for the ``matrixctl update`` command.
+
+    Parameters
+    ----------
+    subparsers : argparse._SubParsersAction
+        The object which is returned by ``parser.add_subparsers()``.
+
+    Returns
+    -------
+    None
+
+    """
     parser: ArgumentParser = subparsers.add_parser(
         "update", help="Updates the ansible repo"
     )
@@ -36,9 +51,22 @@ def subparser_update(subparsers: SubParsersAction) -> None:
 
 
 def update(_: Namespace) -> int:
-    with TOML() as toml:
-        with Git(toml.get(("SYNAPSE", "Playbook"))) as git:
-            git.pull()
+    """Update the synapse playbook with git.
+
+    Parameters
+    ----------
+    arg : argparse.Namespace
+        The ``Namespace`` object of argparse's ``parse_args()``.
+
+    Returns
+    -------
+    err_code : int
+        Non-zero value indicates error code, or zero on success.
+
+    """
+    toml: TOML = TOML()
+    git: Git = Git(toml.get("SYNAPSE", "Playbook"))
+    git.pull()
 
     return 0
 
